==> toycars-0.2.5.tar.gz: toycars-0.2.5/src/Scoobie/ScTilemap.h <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  ScTilemap.h
 *  Scoobie
 *
 *  Created by Ruben Zilibowitz on 25/11/04.
 *
 */

#ifndef SCTILEMAP_H
#define SCTILEMAP_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "ScTypes.h"
#include "ScPanel.h"

class ScTilemap : public ScPanel
{
public:
				ScTilemap(const ScPixelData& pixelData, int inTileWidth, int inTileHeight, short border, short inSeperation = 0, bool inBlend = false);
	virtual		~ScTilemap();
	
	virtual void	doDraw();
	
	void		newMap(int cols, int rows, unsigned char clearTile = 0);
	void		loadMap(const char* filename);
	void		saveMap(const char* filename);
	
	// Gets tile at point.
	unsigned char&	getTileAtPoint(ScFloat x, ScFloat y) const
	{ return (*this)(int(x*invTileWidth), int(y*invTileHeight)); }
	
	// Gets tile at row and column. Clamps to map bounds.
	unsigned char&	operator()(unsigned short col, unsigned short row) const
	{ return map[(row <? (mapHeight-1))*mapWidth + (col <? (mapWidth-1))]; }
	
	unsigned short	getTileWidth() const { return tileWidth; }
	unsigned short	getTileHeight() const { return tileHeight; }
	
	unsigned short	getMapWidth() const { return mapWidth; }
	unsigned short	getMapHeight() const { return mapHeight; }
	
	unsigned char const *	getMapData() const { return map; }
	
protected:
	void	drawTile(ScFloat x, ScFloat y, int tile);
	
	void	loadTiles(const ScPixelData& pixelData, int inTileWidth, int inTileHeight, short border, short inSeperation);
	
	unsigned short	tileWidth, tileHeight;			// tile size in pixels
	unsigned short	textureWidth, textureHeight;	// tiles texture size in pixels
	unsigned short	paletteWidth, paletteHeight;	// tiles texture size in tiles
	unsigned short	mapWidth, mapHeight;			// map dimensions in tiles
	unsigned short	seperation;			// number of pixels seperating adjacent tiles on palette
	
	ScFloat			invTileWidth, invTileHeight;
	ScFloat			invTextureWidth, invTextureHeight;
	
	bool			useBorder;
	bool			useBlending;
	
	GLuint			tex_id;
	unsigned char*	map;
};

#endif

==> toycars-0.3.0.tar.gz: toycars-0.3.0/src/Scoobie/ScTilemap.h <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  ScTilemap.h
 *  Scoobie
 *
 *  Created by Ruben Zilibowitz on 25/11/04.
 *
 */

#ifndef SCTILEMAP_H
#define SCTILEMAP_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "ScTypes.h"
#include "ScPanel.h"

#include <algorithm>

class ScTilemap : public ScPanel
{
public:
				ScTilemap(const ScPixelData& pixelData, int inTileWidth, int inTileHeight, short border, short inSeperation = 0, bool inBlend = false);
	virtual		~ScTilemap();
	
	virtual void	doDraw();
	
	void		newMap(int cols, int rows, unsigned char clearTile = 0);
	void		loadMap(const char* filename);
	void		saveMap(const char* filename);
	
	// Gets tile at point.
	unsigned char&	getTileAtPoint(ScFloat x, ScFloat y) const
	{ return (*this)(int(x*invTileWidth), int(y*invTileHeight)); }
	
	// Gets tile at row and column. Clamps to map bounds.
	unsigned char&	operator()(unsigned short col, unsigned short row) const
	{ return map[std::min((int)row, (mapHeight-1))*mapWidth + std::min((int)col, (mapWidth-1))]; }
	
	unsigned short	getTileWidth() const { return tileWidth; }
	unsigned short	getTileHeight() const { return tileHeight; }
	
	unsigned short	getMapWidth() const { return mapWidth; }
	unsigned short	getMapHeight() const { return mapHeight; }
	
	unsigned char const *	getMapData() const { return map; }
	
protected:
	void	drawTile(ScFloat x, ScFloat y, int tile);
	
	void	loadTiles(const ScPixelData& pixelData, int inTileWidth, int inTileHeight, short border, short inSeperation);
	
	unsigned short	tileWidth, tileHeight;			// tile size in pixels
	unsigned short	textureWidth, textureHeight;	// tiles texture size in pixels
	unsigned short	paletteWidth, paletteHeight;	// tiles texture size in tiles
	unsigned short	mapWidth, mapHeight;			// map dimensions in tiles
	unsigned short	seperation;			// number of pixels seperating adjacent tiles on palette
	
	ScFloat			invTileWidth, invTileHeight;
	ScFloat			invTextureWidth, invTextureHeight;
	
	bool			useBorder;
	bool			useBlending;
	
	GLuint			tex_id;
	unsigned char*	map;
};

#endif
